with Ada.Text_Io; use Ada.Text_IO;
with Ada.Integer_Text_IO; use Ada.Integer_Text_IO;

procedure SimpleCommandProcessor is

type CommandType is (One, Two, Three, Quit, Help);
package Commands_Io is new Ada.Text_IO.Enumeration_IO (Enum => CommandType);
use Commands_Io;

type GenderType is (Female, Male);
package Gender_Io is new Ada.Text_IO.Enumeration_IO (Enum => GenderType);
use Gender_Io;

procedure DisplayHelp is
begin
New_Line;
Put_Line ("  Here is a list of available commands");
Put_Line ("    One <string(1..10)> <integer>");
Put_Line ("    Two <string(1..10)> <gender>");
Put_Line ("    Three ");
Put_Line ("    Quit");
Put_Line ("    Help");
New_Line;
end;

subtype StrType is String(1..10);

Command     : CommandType;
Gender      : GenderType;
Int         : Integer;
Str         : StrType;
StrLength   : Natural;

procedure GetString (S : out StrType; Length : out Natural) is
I    : Natural;
Char : Character;
begin
-- Skip leading white space, ignoring end-of-lines
loop
Get (Char);
exit when Char /= ' ';
end loop;

-- Get letters in the name
I := 0;
loop
exit when not (Char in 'a'..'z') and not (Char in  'A'..'Z');
I := I + 1;
S(I) := Char;  
exit when End_Of_Line;
Get (Char);
exit when Char = ' ';
end loop;
Length := I;
if Length = 0 then
raise Constraint_Error;
end if;
end;

procedure GetCommand  is
begin
loop
begin
Put ("Command: ");
Get (Command);
if Command = One then
GetString (Str, StrLength);
Get (Int);
elsif Command = Two then
GetString (Str, StrLength);
Get (Gender);
end if;
Skip_Line;
exit;
exception
when Data_Error =>
Skip_Line;
Put_Line ("  data error");
when Constraint_Error =>
Skip_Line;
Put_Line ("  constraint error");
end;
end loop;
end;

begin
DisplayHelp;
loop
GetCommand;
case Command is
when One =>
Put ("  ");
Put (Command);
Put (" ");
Put (Str(1..StrLength));
Put (" ");
Put (Int, 0);
when Two =>
Put ("  ");
Put (Command);
Put (" ");
Put (Str(1..StrLength));
Put (" ");
Put (Gender);
when Three =>
Put ("  ");
Put (Command);
when Quit =>
exit;
when Help =>
DisplayHelp;
end case;
New_Line;
end loop;
end SimpleCommandProcessor;
